@@ -277,14 +277,15 @@ sub delete_files {
 	my @ownfiles = sort({$a->url cmp $b->url} @{$self->children});
 	my @to_delete = ();
 
-	do {
+	while(scalar(@names) && scalar(@ownfiles)) {
 		if($ownfiles[0]->is_collection) {
 			if($names[0] eq $ownfiles[0]->baseurl) {
 				push @to_delete, shift @ownfiles;
+				shift @names;
 			} elsif(substr($names[0], 0, length($ownfiles[0]->baseurl)) eq $ownfiles[0]->baseurl) {
 				$ownfiles[0]->delete_files(files => [$names[0]]);
+				shift @names;
 			}
-			shift @names;
 			shift @ownfiles;
 		} elsif($names[0] eq $ownfiles[0]->url) {
 			shift @names;
@@ -300,7 +301,7 @@ sub delete_files {
 			carp "${names[0]} is not a member of this collection, ignored";
 			shift @names;
 		}
-	} while(scalar(@names) && scalar(@ownfiles));
+	};
 	if(scalar(@names)) {
 		carp "${names[0]} is not a member of this collection, ignored";
 	}
@@ -312,7 +313,7 @@ sub delete_files {
 sub delete {
 	my $self = shift;
 
-	foreach my $child($self->children) {
+	foreach my $child(@{$self->children}) {
 		$child->delete;
 	}
 }
