@@ -103,6 +103,7 @@ sub update {
 			$c->render(variant => "error");
 			return;
 		}
+                $talk->add_correction(serial => -1);
                 $talk->done_correcting;
                 $talk->state_done("preview");
                 $c->render(variant => 'done');
@@ -176,7 +177,7 @@ sub data {
 
         my $data = $talk->corrected_times;
 	$c->app->log->debug($talk->video_fragments);
-        $data->{filename} = $talk->relative_name . "." . $c->srconfig->get("preview_exten");
+        $data->{filename} = $talk->relative_name . "/main" . $c->srconfig->get("preview_exten");
         $data->{room} = $talk->room;
 
         $c->render(json => $data);
